# Changelog

## 4.13.0 (2025-01-03)

Full Changelog: [v4.12.0...v4.13.0](https://github.com/RetellAI/retell-python-sdk/compare/v4.12.0...v4.13.0)

### Features

* **api:** api update ([#244](https://github.com/RetellAI/retell-python-sdk/issues/244)) ([0dd2989](https://github.com/RetellAI/retell-python-sdk/commit/0dd2989f7f407d52120b36a52acbff44c4bf56e1))


### Chores

* **internal:** codegen related update ([#242](https://github.com/RetellAI/retell-python-sdk/issues/242)) ([41122d6](https://github.com/RetellAI/retell-python-sdk/commit/41122d6051a8f8ac84bfb67a9a309bc820914d2d))

## 4.12.0 (2024-12-27)

Full Changelog: [v4.11.1...v4.12.0](https://github.com/RetellAI/retell-python-sdk/compare/v4.11.1...v4.12.0)

### Features

* **api:** api update ([#238](https://github.com/RetellAI/retell-python-sdk/issues/238)) ([0d12871](https://github.com/RetellAI/retell-python-sdk/commit/0d128717359dae474f8a18ec25d4dd03e964daa5))
* **api:** api update ([#239](https://github.com/RetellAI/retell-python-sdk/issues/239)) ([80ac9de](https://github.com/RetellAI/retell-python-sdk/commit/80ac9dedf50e3f70f891acdc260989df160f5a8d))
* **api:** api update ([#240](https://github.com/RetellAI/retell-python-sdk/issues/240)) ([5a3b444](https://github.com/RetellAI/retell-python-sdk/commit/5a3b444acc9871abf8d3dcd7be0c745c9bee8a2f))
* remove uesless test ([01a09b7](https://github.com/RetellAI/retell-python-sdk/commit/01a09b7a5372c6ae732e491641ca16c028567eaa))


### Chores

* **internal:** add support for TypeAliasType ([#234](https://github.com/RetellAI/retell-python-sdk/issues/234)) ([6b28299](https://github.com/RetellAI/retell-python-sdk/commit/6b2829901b2883d07d4f58c4c83a8f5972d7576b))
* **internal:** bump pyright ([#232](https://github.com/RetellAI/retell-python-sdk/issues/232)) ([dc804e8](https://github.com/RetellAI/retell-python-sdk/commit/dc804e8d8953caedb89d6f781f53e0fa11344c64))
* **internal:** fix some typos ([#237](https://github.com/RetellAI/retell-python-sdk/issues/237)) ([e46e933](https://github.com/RetellAI/retell-python-sdk/commit/e46e933a5051cfdd6e3914a936a6105b42d62a90))
* **internal:** updated imports ([#235](https://github.com/RetellAI/retell-python-sdk/issues/235)) ([2713fb1](https://github.com/RetellAI/retell-python-sdk/commit/2713fb1ab4a2b72c4777fdb384eef0109bbcd4e6))


### Documentation

* **readme:** example snippet for client context manager ([#236](https://github.com/RetellAI/retell-python-sdk/issues/236)) ([95b8f34](https://github.com/RetellAI/retell-python-sdk/commit/95b8f3445b1802ab294c7b3df2549fae1953b6af))

## 4.11.1 (2024-12-09)

Full Changelog: [v4.11.0...v4.11.1](https://github.com/RetellAI/retell-python-sdk/compare/v4.11.0...v4.11.1)

### Chores

* **internal:** bump pydantic dependency ([#227](https://github.com/RetellAI/retell-python-sdk/issues/227)) ([0ddec04](https://github.com/RetellAI/retell-python-sdk/commit/0ddec044da39420f9b43549841db8c5fca8eda97))
* make the `Omit` type public ([#225](https://github.com/RetellAI/retell-python-sdk/issues/225)) ([ac96de0](https://github.com/RetellAI/retell-python-sdk/commit/ac96de09bc9d65a0f3435953dbede0740ad17e63))


### Documentation

* **readme:** fix http client proxies example ([#229](https://github.com/RetellAI/retell-python-sdk/issues/229)) ([0b59722](https://github.com/RetellAI/retell-python-sdk/commit/0b59722f7e65e1f78f43d888f036eede41d0b68f))

## 4.11.0 (2024-12-03)

Full Changelog: [v4.10.0...v4.11.0](https://github.com/RetellAI/retell-python-sdk/compare/v4.10.0...v4.11.0)

### Features

* Fix httpx dependencies ([4730cd9](https://github.com/RetellAI/retell-python-sdk/commit/4730cd9f770f46a86ebfab72da1bc1625babfbf8))
* fix: knowledge base api boolean ([8c06ce9](https://github.com/RetellAI/retell-python-sdk/commit/8c06ce9a9deaa9806d6086dcfb6047150c9e9b5f))


### Bug Fixes

* add missing cryptography dependency ([be4cbd9](https://github.com/RetellAI/retell-python-sdk/commit/be4cbd9727a3dac055139bd39a5668e98a8cf3df))
* knowledge base api boolean ([436c09d](https://github.com/RetellAI/retell-python-sdk/commit/436c09d8c5421654d5f1e28c00353210524e954d))
* serialization logic for multipartform for non-string keys ([489a198](https://github.com/RetellAI/retell-python-sdk/commit/489a198b6af5bc763d687c9b9acbb7e1ca4f758b))


### Chores

* bump ([806aae6](https://github.com/RetellAI/retell-python-sdk/commit/806aae6700a28dada4c569561e88b92aeea7cd28))
* fix formatting ([cf1a618](https://github.com/RetellAI/retell-python-sdk/commit/cf1a6189861640f87debf6aed738aef2ade76f46))
* **internal:** bump pyright ([#222](https://github.com/RetellAI/retell-python-sdk/issues/222)) ([d855687](https://github.com/RetellAI/retell-python-sdk/commit/d855687de9e0c1a688a14bd4692fb31ad869e4c8))
* **tests:** update multipart test values ([1943d93](https://github.com/RetellAI/retell-python-sdk/commit/1943d93617fee96b0de17de72d67d40a170349de))
* warn if serializing a non-string key ([b23ccc0](https://github.com/RetellAI/retell-python-sdk/commit/b23ccc0cce5b154d7a46467932445231e61ae194))

## 4.10.0 (2024-11-29)

Full Changelog: [v4.9.0...v4.10.0](https://github.com/RetellAI/retell-python-sdk/compare/v4.9.0...v4.10.0)

### Features

* **api:** api update ([#217](https://github.com/RetellAI/retell-python-sdk/issues/217)) ([282956d](https://github.com/RetellAI/retell-python-sdk/commit/282956d1aac75aeec7587aaa763d9967b0b3edc3))
* **api:** api update ([#219](https://github.com/RetellAI/retell-python-sdk/issues/219)) ([05ad70e](https://github.com/RetellAI/retell-python-sdk/commit/05ad70eefff255ab68ba14f98b304e5231f4c8f1))
* fix: fix tests ([466239b](https://github.com/RetellAI/retell-python-sdk/commit/466239bd2aabb6f1d7be242b8a580aed748efa34))
* fix: knowledge base api ([1dcf6ee](https://github.com/RetellAI/retell-python-sdk/commit/1dcf6eeb3c1da27928b7318c39aa43039b44fbb4))

## 4.9.0 (2024-11-28)

Full Changelog: [v4.8.0...v4.9.0](https://github.com/RetellAI/retell-python-sdk/compare/v4.8.0...v4.9.0)

### Features

* **api:** api update ([#202](https://github.com/RetellAI/retell-python-sdk/issues/202)) ([8b74190](https://github.com/RetellAI/retell-python-sdk/commit/8b74190c18f22e2e25b926b744905bc3a7e5e369))


### Bug Fixes

* **client:** compat with new httpx 0.28.0 release ([#215](https://github.com/RetellAI/retell-python-sdk/issues/215)) ([962f440](https://github.com/RetellAI/retell-python-sdk/commit/962f4400fd242097cd960c66aaa69f745b42da58))


### Chores

* **internal:** exclude mypy from running on tests ([#212](https://github.com/RetellAI/retell-python-sdk/issues/212)) ([6b8890b](https://github.com/RetellAI/retell-python-sdk/commit/6b8890bcfbad412e9c2e9e3aac9119921f788f85))
* **internal:** fix compat model_dump method when warnings are passed ([#208](https://github.com/RetellAI/retell-python-sdk/issues/208)) ([129bf7f](https://github.com/RetellAI/retell-python-sdk/commit/129bf7f2104b752da5a7c649779d1dc5b8c54402))
* rebuild project due to codegen change ([#204](https://github.com/RetellAI/retell-python-sdk/issues/204)) ([73ef71b](https://github.com/RetellAI/retell-python-sdk/commit/73ef71b0769299dc84091718ea77d7b06bca11a0))
* rebuild project due to codegen change ([#205](https://github.com/RetellAI/retell-python-sdk/issues/205)) ([41aecf5](https://github.com/RetellAI/retell-python-sdk/commit/41aecf5ca2df9da925417d812d0e87b1fb45c63d))
* rebuild project due to codegen change ([#206](https://github.com/RetellAI/retell-python-sdk/issues/206)) ([dc300ff](https://github.com/RetellAI/retell-python-sdk/commit/dc300fff5cd0b3ee1af5018cb7445e7df0ab0746))
* rebuild project due to codegen change ([#207](https://github.com/RetellAI/retell-python-sdk/issues/207)) ([db3cdc0](https://github.com/RetellAI/retell-python-sdk/commit/db3cdc051e04132cc280b12b2f15204eb8b979ab))
* remove now unused `cached-property` dep ([#210](https://github.com/RetellAI/retell-python-sdk/issues/210)) ([e164f74](https://github.com/RetellAI/retell-python-sdk/commit/e164f7463e25aa4a9889cd863cf93db90f20fddc))


### Documentation

* add info log level to readme ([#209](https://github.com/RetellAI/retell-python-sdk/issues/209)) ([8b6e2ef](https://github.com/RetellAI/retell-python-sdk/commit/8b6e2ef6f43fa2232d91ae5ae00bbffb948849ed))

## 4.8.0 (2024-11-03)

Full Changelog: [v4.7.0...v4.8.0](https://github.com/RetellAI/retell-python-sdk/compare/v4.7.0...v4.8.0)

### Features

* **api:** api update ([#199](https://github.com/RetellAI/retell-python-sdk/issues/199)) ([b2069ad](https://github.com/RetellAI/retell-python-sdk/commit/b2069adcaf44e12bb7e3a3bfa780b939abd72497))

## 4.7.0 (2024-10-31)

Full Changelog: [v4.6.0...v4.7.0](https://github.com/RetellAI/retell-python-sdk/compare/v4.6.0...v4.7.0)

### Features

* **api:** api update ([#193](https://github.com/RetellAI/retell-python-sdk/issues/193)) ([46ae92b](https://github.com/RetellAI/retell-python-sdk/commit/46ae92bc17b9d4d9ba193a1d4e91b802f121ec1a))
* **api:** api update ([#194](https://github.com/RetellAI/retell-python-sdk/issues/194)) ([83c4c37](https://github.com/RetellAI/retell-python-sdk/commit/83c4c37100917a0afb7845f24a9ea5b984741026))
* **api:** api update ([#196](https://github.com/RetellAI/retell-python-sdk/issues/196)) ([e897b96](https://github.com/RetellAI/retell-python-sdk/commit/e897b96750faf297c4f4c109ffd49a8fee4c330a))
* **api:** api update ([#197](https://github.com/RetellAI/retell-python-sdk/issues/197)) ([a8a624a](https://github.com/RetellAI/retell-python-sdk/commit/a8a624a783fc47dfcced476c855974d537e6df56))
* **api:** OpenAPI spec update via Stainless API ([#190](https://github.com/RetellAI/retell-python-sdk/issues/190)) ([e98859b](https://github.com/RetellAI/retell-python-sdk/commit/e98859be145a4148664131f6d33c9ea811274a5b))


### Bug Fixes

* **internal:** fix is_basemodel_type ([6af7cf4](https://github.com/RetellAI/retell-python-sdk/commit/6af7cf4792061daa0b8c4c67d6de0b5bbaf0c818))


### Chores

* **internal:** bump pyright / mypy version ([#189](https://github.com/RetellAI/retell-python-sdk/issues/189)) ([29a9814](https://github.com/RetellAI/retell-python-sdk/commit/29a98145c4cf0ceec56c33d95933c4dabf9b3521))
* **internal:** bump ruff ([#188](https://github.com/RetellAI/retell-python-sdk/issues/188)) ([bd939c2](https://github.com/RetellAI/retell-python-sdk/commit/bd939c2475ba709ff65684bb87dd3b56d398e72f))
* **internal:** codegen related update ([#191](https://github.com/RetellAI/retell-python-sdk/issues/191)) ([fbfd28d](https://github.com/RetellAI/retell-python-sdk/commit/fbfd28da765d0c030b8bef0b67fed8db43bdb92e))
* **internal:** codegen related update ([#192](https://github.com/RetellAI/retell-python-sdk/issues/192)) ([ebfc813](https://github.com/RetellAI/retell-python-sdk/commit/ebfc8133ad3b96c963a62fed77736320cbb581b8))


### Documentation

* update CONTRIBUTING.md ([#185](https://github.com/RetellAI/retell-python-sdk/issues/185)) ([a939411](https://github.com/RetellAI/retell-python-sdk/commit/a9394111a918e04b72b1b6e4fdc49ad146172820))

## 4.6.0 (2024-09-17)

Full Changelog: [v4.5.0...v4.6.0](https://github.com/RetellAI/retell-python-sdk/compare/v4.5.0...v4.6.0)

### Features

* **api:** OpenAPI spec update via Stainless API ([#183](https://github.com/RetellAI/retell-python-sdk/issues/183)) ([b85bb33](https://github.com/RetellAI/retell-python-sdk/commit/b85bb33bb623f09290e1258b487c3a1ce613549a))

## 4.5.0 (2024-09-10)

Full Changelog: [v4.4.0...v4.5.0](https://github.com/RetellAI/retell-python-sdk/compare/v4.4.0...v4.5.0)

### Features

* **api:** OpenAPI spec update via Stainless API ([#176](https://github.com/RetellAI/retell-python-sdk/issues/176)) ([998682e](https://github.com/RetellAI/retell-python-sdk/commit/998682efa7001dd318cb372cf4311cd70a7179d3))


### Chores

* add docstrings to raw response properties ([#180](https://github.com/RetellAI/retell-python-sdk/issues/180)) ([fd726fe](https://github.com/RetellAI/retell-python-sdk/commit/fd726fe37fb0817d81c1c371404dde2148854229))
* pyproject.toml formatting changes ([#178](https://github.com/RetellAI/retell-python-sdk/issues/178)) ([7f18a3c](https://github.com/RetellAI/retell-python-sdk/commit/7f18a3c2ef2ad4585e30e03db6e8074ba19b4a75))

## 4.4.0 (2024-09-04)

Full Changelog: [v4.3.0...v4.4.0](https://github.com/RetellAI/retell-python-sdk/compare/v4.3.0...v4.4.0)

### Features

* **api:** OpenAPI spec update via Stainless API ([#173](https://github.com/RetellAI/retell-python-sdk/issues/173)) ([6910a3e](https://github.com/RetellAI/retell-python-sdk/commit/6910a3e17aad00378066e007c5b3566a1384197e))

## 4.3.0 (2024-08-16)

Full Changelog: [v4.2.0...v4.3.0](https://github.com/RetellAI/retell-python-sdk/compare/v4.2.0...v4.3.0)

### Features

* **api:** OpenAPI spec update via Stainless API ([#151](https://github.com/RetellAI/retell-python-sdk/issues/151)) ([f562aa4](https://github.com/RetellAI/retell-python-sdk/commit/f562aa4332614db8225d87f5b0089936231f0d8d))
* **api:** OpenAPI spec update via Stainless API ([#160](https://github.com/RetellAI/retell-python-sdk/issues/160)) ([5099f5e](https://github.com/RetellAI/retell-python-sdk/commit/5099f5e179e19633ac30e4ab2ab3a1ea7d730b8e))
* **api:** OpenAPI spec update via Stainless API ([#164](https://github.com/RetellAI/retell-python-sdk/issues/164)) ([c43e921](https://github.com/RetellAI/retell-python-sdk/commit/c43e92118abf709554d8e27a1a5d10c4c3fbd057))
* **api:** OpenAPI spec update via Stainless API ([#167](https://github.com/RetellAI/retell-python-sdk/issues/167)) ([de17f28](https://github.com/RetellAI/retell-python-sdk/commit/de17f28b9b7cdecd9df11f643f8c0b1f3bb25520))
* **api:** OpenAPI spec update via Stainless API ([#168](https://github.com/RetellAI/retell-python-sdk/issues/168)) ([072caf3](https://github.com/RetellAI/retell-python-sdk/commit/072caf3f502734679146a509be73c8632678eea4))
* **client:** add `retry_count` to raw response class ([#155](https://github.com/RetellAI/retell-python-sdk/issues/155)) ([e486f13](https://github.com/RetellAI/retell-python-sdk/commit/e486f1335037ce56a154692edf1f2ad2e21cb8ac))


### Chores

* **ci:** bump prism mock server version ([#162](https://github.com/RetellAI/retell-python-sdk/issues/162)) ([898ad43](https://github.com/RetellAI/retell-python-sdk/commit/898ad43ecb89cb1b0e96b7c64947406d375e73dc))
* **examples:** minor formatting changes ([#166](https://github.com/RetellAI/retell-python-sdk/issues/166)) ([ce9b846](https://github.com/RetellAI/retell-python-sdk/commit/ce9b846eb6f7f0d05df795805d45530eb154f2ac))
* **internal:** bump pyright ([#154](https://github.com/RetellAI/retell-python-sdk/issues/154)) ([372900e](https://github.com/RetellAI/retell-python-sdk/commit/372900ea6bd723c01b2f19d446e1bac29aca0ba9))
* **internal:** bump ruff version ([#157](https://github.com/RetellAI/retell-python-sdk/issues/157)) ([04ebe96](https://github.com/RetellAI/retell-python-sdk/commit/04ebe968e683ef3b5c97195cd4f6ac03348c467e))
* **internal:** codegen related update ([#165](https://github.com/RetellAI/retell-python-sdk/issues/165)) ([940dce4](https://github.com/RetellAI/retell-python-sdk/commit/940dce4aedb77317c3087ffa10e630106110862a))
* **internal:** codegen related update ([#169](https://github.com/RetellAI/retell-python-sdk/issues/169)) ([5f9b799](https://github.com/RetellAI/retell-python-sdk/commit/5f9b799ec5fc1ad0ad1b7fb0cbe08899e8948b70))
* **internal:** ensure package is importable in lint cmd ([#163](https://github.com/RetellAI/retell-python-sdk/issues/163)) ([c94cc06](https://github.com/RetellAI/retell-python-sdk/commit/c94cc068ecb0222f80ffd704232d2f0af8dff085))
* **internal:** remove deprecated ruff config ([#161](https://github.com/RetellAI/retell-python-sdk/issues/161)) ([98cf302](https://github.com/RetellAI/retell-python-sdk/commit/98cf302621370de9b9d47c809aa2697100d63566))
* **internal:** test updates ([#156](https://github.com/RetellAI/retell-python-sdk/issues/156)) ([b69760f](https://github.com/RetellAI/retell-python-sdk/commit/b69760fe8a97c6ca6568fd5050e773f04f6add91))
* **internal:** update pydantic compat helper function ([#158](https://github.com/RetellAI/retell-python-sdk/issues/158)) ([d83e081](https://github.com/RetellAI/retell-python-sdk/commit/d83e081fb5d258881c6c7fa14ed07a1be34cec78))
* **internal:** use `TypeAlias` marker for type assignments ([#153](https://github.com/RetellAI/retell-python-sdk/issues/153)) ([32812a1](https://github.com/RetellAI/retell-python-sdk/commit/32812a121030db9e7ca335c0612ca05f26730b6c))
* **internal:** use different 32bit detection method ([#170](https://github.com/RetellAI/retell-python-sdk/issues/170)) ([e3cdc9c](https://github.com/RetellAI/retell-python-sdk/commit/e3cdc9cff36b9f22b803669baddc7ef467012db2))

## 4.2.0 (2024-08-07)

Full Changelog: [v4.1.0...v4.2.0](https://github.com/RetellAI/retell-python-sdk/compare/v4.1.0...v4.2.0)

### Features

* **api:** OpenAPI spec update via Stainless API ([#148](https://github.com/RetellAI/retell-python-sdk/issues/148)) ([f9bfbd3](https://github.com/RetellAI/retell-python-sdk/commit/f9bfbd3b41abd53e59ee116e317d944ea1241b7b))

## 4.1.0 (2024-07-31)

Full Changelog: [v4.0.0...v4.1.0](https://github.com/RetellAI/retell-python-sdk/compare/v4.0.0...v4.1.0)

### Features

* **api:** OpenAPI spec update via Stainless API ([#140](https://github.com/RetellAI/retell-python-sdk/issues/140)) ([053c851](https://github.com/RetellAI/retell-python-sdk/commit/053c851ce2054c86260500d6a2dadb7acf010662))
* **api:** OpenAPI spec update via Stainless API ([#146](https://github.com/RetellAI/retell-python-sdk/issues/146)) ([b867c45](https://github.com/RetellAI/retell-python-sdk/commit/b867c45c3943069f062c9746ce3263131ef280e2))


### Chores

* fix error message import example ([#144](https://github.com/RetellAI/retell-python-sdk/issues/144)) ([2efeb89](https://github.com/RetellAI/retell-python-sdk/commit/2efeb8952315d488eff27c669b89acc40ec63b26))
* **internal:** add type construction helper ([#145](https://github.com/RetellAI/retell-python-sdk/issues/145)) ([e9af78c](https://github.com/RetellAI/retell-python-sdk/commit/e9af78c22d646621c1454ced09ec17bce586a5cc))
* **internal:** codegen related update ([#142](https://github.com/RetellAI/retell-python-sdk/issues/142)) ([bde4f77](https://github.com/RetellAI/retell-python-sdk/commit/bde4f77d9af597a59c77c73f559511ed8ed032f8))
* **tests:** update prism version ([#143](https://github.com/RetellAI/retell-python-sdk/issues/143)) ([b7d2019](https://github.com/RetellAI/retell-python-sdk/commit/b7d201954e451dece6d759f88e0a5b5cc59ab39e))

## 4.0.0 (2024-07-08)

Full Changelog: [v3.20.0...v4.0.0](https://github.com/RetellAI/retell-python-sdk/compare/v3.20.0...v4.0.0)

### Features

* **api:** OpenAPI spec update via Stainless API ([#137](https://github.com/RetellAI/retell-python-sdk/issues/137)) ([ef87cfa](https://github.com/RetellAI/retell-python-sdk/commit/ef87cfae862e10e943cf6166a8edadb3abaafa60))

## 3.20.0 (2024-07-01)

Full Changelog: [v3.19.0...v3.20.0](https://github.com/RetellAI/retell-python-sdk/compare/v3.19.0...v3.20.0)

### Features

* **api:** manual updates ([#132](https://github.com/RetellAI/retell-python-sdk/issues/132)) ([4cb9aa5](https://github.com/RetellAI/retell-python-sdk/commit/4cb9aa511ae40b89071fed63e0d9597de5541ec2))
* **api:** manual updates ([#134](https://github.com/RetellAI/retell-python-sdk/issues/134)) ([cf92a06](https://github.com/RetellAI/retell-python-sdk/commit/cf92a06417790da71b376eead97335a9c269f745))
* **api:** OpenAPI spec update via Stainless API ([#135](https://github.com/RetellAI/retell-python-sdk/issues/135)) ([c7d47d7](https://github.com/RetellAI/retell-python-sdk/commit/c7d47d76b177b614246fd3aa4fe6cbf31d6b2675))

## 3.19.0 (2024-07-01)

Full Changelog: [v3.18.0...v3.19.0](https://github.com/RetellAI/retell-python-sdk/compare/v3.18.0...v3.19.0)

### Features

* **api:** OpenAPI spec update via Stainless API ([#119](https://github.com/RetellAI/retell-python-sdk/issues/119)) ([18c6154](https://github.com/RetellAI/retell-python-sdk/commit/18c61544264369c882bf3c2505bcaa6378148c3e))
* **api:** OpenAPI spec update via Stainless API ([#121](https://github.com/RetellAI/retell-python-sdk/issues/121)) ([ae5868e](https://github.com/RetellAI/retell-python-sdk/commit/ae5868edb0fd3af092027708594e748f235f5189))
* **api:** OpenAPI spec update via Stainless API ([#122](https://github.com/RetellAI/retell-python-sdk/issues/122)) ([22c79c7](https://github.com/RetellAI/retell-python-sdk/commit/22c79c72ab2038d614a75acab6290184efedb978))
* **api:** OpenAPI spec update via Stainless API ([#123](https://github.com/RetellAI/retell-python-sdk/issues/123)) ([b4f187c](https://github.com/RetellAI/retell-python-sdk/commit/b4f187cf5e324b64161052b20a9fdb2e1ca59b48))
* **api:** OpenAPI spec update via Stainless API ([#124](https://github.com/RetellAI/retell-python-sdk/issues/124)) ([577c939](https://github.com/RetellAI/retell-python-sdk/commit/577c939bf49272b170938bf5686aaeafcff7ba5f))
* **api:** OpenAPI spec update via Stainless API ([#125](https://github.com/RetellAI/retell-python-sdk/issues/125)) ([fe98d7e](https://github.com/RetellAI/retell-python-sdk/commit/fe98d7e86c8559266a9add5ea96b64cb12db2ce2))
* **api:** OpenAPI spec update via Stainless API ([#126](https://github.com/RetellAI/retell-python-sdk/issues/126)) ([ccef7fb](https://github.com/RetellAI/retell-python-sdk/commit/ccef7fb7e646ffa0f7bb1e9e53478a068837e5f8))
* **api:** OpenAPI spec update via Stainless API ([#127](https://github.com/RetellAI/retell-python-sdk/issues/127)) ([c4c65b1](https://github.com/RetellAI/retell-python-sdk/commit/c4c65b1f3dc988a2b7f090f3630bb5f114e21c03))
* **api:** OpenAPI spec update via Stainless API ([#128](https://github.com/RetellAI/retell-python-sdk/issues/128)) ([44ba1ed](https://github.com/RetellAI/retell-python-sdk/commit/44ba1ed9a48766bfb511fa3c9e9d272b333df84f))
* **api:** OpenAPI spec update via Stainless API ([#129](https://github.com/RetellAI/retell-python-sdk/issues/129)) ([971b2c7](https://github.com/RetellAI/retell-python-sdk/commit/971b2c7de442dd264b2fcca2bf1ec9d290743351))

## 3.18.0 (2024-06-06)

Full Changelog: [v3.17.0...v3.18.0](https://github.com/RetellAI/retell-python-sdk/compare/v3.17.0...v3.18.0)

### Features

* **api:** OpenAPI spec update via Stainless API ([#108](https://github.com/RetellAI/retell-python-sdk/issues/108)) ([73424e3](https://github.com/RetellAI/retell-python-sdk/commit/73424e38af207759d9fe06ba5b8331084fe0383e))
* **api:** OpenAPI spec update via Stainless API ([#110](https://github.com/RetellAI/retell-python-sdk/issues/110)) ([a905225](https://github.com/RetellAI/retell-python-sdk/commit/a9052251dee723affde699de25005ef7938cd5e6))
* **api:** OpenAPI spec update via Stainless API ([#111](https://github.com/RetellAI/retell-python-sdk/issues/111)) ([4243ead](https://github.com/RetellAI/retell-python-sdk/commit/4243ead63925b997a780892b961a5e19b64d80bb))
* **api:** OpenAPI spec update via Stainless API ([#112](https://github.com/RetellAI/retell-python-sdk/issues/112)) ([3ad4a2d](https://github.com/RetellAI/retell-python-sdk/commit/3ad4a2dd30b0d1582c04a2231e7b61fcf01128c3))
* **api:** OpenAPI spec update via Stainless API ([#113](https://github.com/RetellAI/retell-python-sdk/issues/113)) ([d0d0ef2](https://github.com/RetellAI/retell-python-sdk/commit/d0d0ef23ba863e18a6c92c3851a0e8ca2e4c4180))
* **api:** OpenAPI spec update via Stainless API ([#114](https://github.com/RetellAI/retell-python-sdk/issues/114)) ([f479ed8](https://github.com/RetellAI/retell-python-sdk/commit/f479ed89c8c8e98cbbf12dc8fced478b5f79adb2))
* **api:** OpenAPI spec update via Stainless API ([#115](https://github.com/RetellAI/retell-python-sdk/issues/115)) ([f382379](https://github.com/RetellAI/retell-python-sdk/commit/f3823799fd1ac35fb93d0fad5bbd25ac1ba93e43))
* **api:** OpenAPI spec update via Stainless API ([#116](https://github.com/RetellAI/retell-python-sdk/issues/116)) ([38aa122](https://github.com/RetellAI/retell-python-sdk/commit/38aa1222809618eed1c40a0dc1191792b83ddce1))

## 3.17.0 (2024-06-02)

Full Changelog: [v3.16.0...v3.17.0](https://github.com/RetellAI/retell-python-sdk/compare/v3.16.0...v3.17.0)

### Features

* **api:** manual updates ([#106](https://github.com/RetellAI/retell-python-sdk/issues/106)) ([c15069e](https://github.com/RetellAI/retell-python-sdk/commit/c15069e5f73e06e268fb23edfb5d6b03d1766e9e))
* **api:** OpenAPI spec update via Stainless API ([#104](https://github.com/RetellAI/retell-python-sdk/issues/104)) ([49efca0](https://github.com/RetellAI/retell-python-sdk/commit/49efca0a34944ca93221e0ab8c31ef596df93601))

## 3.16.0 (2024-06-02)

Full Changelog: [v3.15.1...v3.16.0](https://github.com/RetellAI/retell-python-sdk/compare/v3.15.1...v3.16.0)

### Features

* **api:** manual updates ([#102](https://github.com/RetellAI/retell-python-sdk/issues/102)) ([07c03db](https://github.com/RetellAI/retell-python-sdk/commit/07c03dbc7e1292750b0b84a2ada5d1528af922d0))
* **api:** manual updates ([#98](https://github.com/RetellAI/retell-python-sdk/issues/98)) ([34efb1a](https://github.com/RetellAI/retell-python-sdk/commit/34efb1a827e36fe1b560db13c47440f3456a66d4))
* **api:** OpenAPI spec update via Stainless API ([#100](https://github.com/RetellAI/retell-python-sdk/issues/100)) ([13e20f5](https://github.com/RetellAI/retell-python-sdk/commit/13e20f5aa61825e6e820be30ad68384d7107a8a8))
* **api:** OpenAPI spec update via Stainless API ([#101](https://github.com/RetellAI/retell-python-sdk/issues/101)) ([713b30a](https://github.com/RetellAI/retell-python-sdk/commit/713b30ade135ab46824101d4bf18a8592142065e))
* **api:** OpenAPI spec update via Stainless API ([#96](https://github.com/RetellAI/retell-python-sdk/issues/96)) ([1863aa2](https://github.com/RetellAI/retell-python-sdk/commit/1863aa236fa9511d0386293fe9aefd4e55624939))
* **api:** OpenAPI spec update via Stainless API ([#99](https://github.com/RetellAI/retell-python-sdk/issues/99)) ([d87ad31](https://github.com/RetellAI/retell-python-sdk/commit/d87ad3136d6c07ca3da7f7e763b288888b20276c))

## 3.15.1 (2024-05-20)

Full Changelog: [v3.15.0...v3.15.1](https://github.com/RetellAI/retell-python-sdk/compare/v3.15.0...v3.15.1)

### Bug Fixes

* **client:** correct formatting of array query params ([7d91e92](https://github.com/RetellAI/retell-python-sdk/commit/7d91e926042f2ecd5b2a9ece933cbc21eca68925))

## 3.15.0 (2024-05-20)

Full Changelog: [v3.14.0...v3.15.0](https://github.com/RetellAI/retell-python-sdk/compare/v3.14.0...v3.15.0)

### Features

* **api:** OpenAPI spec update via Stainless API ([#87](https://github.com/RetellAI/retell-python-sdk/issues/87)) ([4869186](https://github.com/RetellAI/retell-python-sdk/commit/4869186ef68f3da1246dc6302ec959f065118a21))
* **api:** OpenAPI spec update via Stainless API ([#89](https://github.com/RetellAI/retell-python-sdk/issues/89)) ([49bd112](https://github.com/RetellAI/retell-python-sdk/commit/49bd1129cc05f6c6c113b933510d597038cc8ceb))


### Bug Fixes

* **client:** correct array format for query strings ([069cc04](https://github.com/RetellAI/retell-python-sdk/commit/069cc047958ba69cb5afac7a6dd197391b3801bd))

## 3.14.0 (2024-05-12)

Full Changelog: [v3.13.0...v3.14.0](https://github.com/RetellAI/retell-python-sdk/compare/v3.13.0...v3.14.0)

### Features

* **api:** OpenAPI spec update via Stainless API ([#85](https://github.com/RetellAI/retell-python-sdk/issues/85)) ([28607e1](https://github.com/RetellAI/retell-python-sdk/commit/28607e18888f886c903deb369504def85d9e6926))

## 3.13.0 (2024-05-11)

Full Changelog: [v3.12.0...v3.13.0](https://github.com/RetellAI/retell-python-sdk/compare/v3.12.0...v3.13.0)

### Features

* **api:** manual updates ([#83](https://github.com/RetellAI/retell-python-sdk/issues/83)) ([aafa41c](https://github.com/RetellAI/retell-python-sdk/commit/aafa41cdeabd0104945c64ff5026df2b1e7b86eb))
* **api:** manual updates ([#84](https://github.com/RetellAI/retell-python-sdk/issues/84)) ([e101c16](https://github.com/RetellAI/retell-python-sdk/commit/e101c169c7ff84e7dd1b650955854087c69763f8))
* **api:** OpenAPI spec update via Stainless API ([#79](https://github.com/RetellAI/retell-python-sdk/issues/79)) ([d5b8b30](https://github.com/RetellAI/retell-python-sdk/commit/d5b8b30f2eee346a9ce9c55af7498ca15f621add))
* **api:** OpenAPI spec update via Stainless API ([#81](https://github.com/RetellAI/retell-python-sdk/issues/81)) ([9d14e1d](https://github.com/RetellAI/retell-python-sdk/commit/9d14e1d127d649f010bcd14d9b6e49c70ae281a2))
* **api:** OpenAPI spec update via Stainless API ([#82](https://github.com/RetellAI/retell-python-sdk/issues/82)) ([6ec9a3e](https://github.com/RetellAI/retell-python-sdk/commit/6ec9a3e6d359497f7fd5094a7c3b41f4ca702ce2))

## 3.12.0 (2024-05-01)

Full Changelog: [v3.11.0...v3.12.0](https://github.com/RetellAI/retell-python-sdk/compare/v3.11.0...v3.12.0)

### Features

* **api:** manual updates ([#78](https://github.com/RetellAI/retell-python-sdk/issues/78)) ([26071b4](https://github.com/RetellAI/retell-python-sdk/commit/26071b46c249b322659f1286f1fb1047b87cdda7))
* **api:** OpenAPI spec update via Stainless API ([#75](https://github.com/RetellAI/retell-python-sdk/issues/75)) ([379b4a5](https://github.com/RetellAI/retell-python-sdk/commit/379b4a515eba88e4ddaa6206fd99f0756b18998c))
* **api:** OpenAPI spec update via Stainless API ([#77](https://github.com/RetellAI/retell-python-sdk/issues/77)) ([c3be675](https://github.com/RetellAI/retell-python-sdk/commit/c3be675ec32b1d242928ad28ccef91e72a1e9cc2))

## 3.11.0 (2024-04-26)

Full Changelog: [v3.10.0...v3.11.0](https://github.com/RetellAI/retell-python-sdk/compare/v3.10.0...v3.11.0)

### Features

* add package" ([45b5c3d](https://github.com/RetellAI/retell-python-sdk/commit/45b5c3d2d9ae9a78a5ae8b36b2d306551738176a))
* compile errors ([8a885a2](https://github.com/RetellAI/retell-python-sdk/commit/8a885a231b24cb01a170a9ed3f69ebbdde496459))
* webhook security ([b5fa4bd](https://github.com/RetellAI/retell-python-sdk/commit/b5fa4bdf9d9bc76b80394de405f1925ba1d8113d))

## 3.10.0 (2024-04-26)

Full Changelog: [v3.9.0...v3.10.0](https://github.com/RetellAI/retell-python-sdk/compare/v3.9.0...v3.10.0)

### Features

* **api:** OpenAPI spec update via Stainless API ([#69](https://github.com/RetellAI/retell-python-sdk/issues/69)) ([5359b55](https://github.com/RetellAI/retell-python-sdk/commit/5359b55ec7daa7e2987b04358b70c0cb6e639868))
* **api:** OpenAPI spec update via Stainless API ([#71](https://github.com/RetellAI/retell-python-sdk/issues/71)) ([6dace9c](https://github.com/RetellAI/retell-python-sdk/commit/6dace9cc396322519f2e8dbc18fcb5704460c208))
* **api:** OpenAPI spec update via Stainless API ([#72](https://github.com/RetellAI/retell-python-sdk/issues/72)) ([f0828c0](https://github.com/RetellAI/retell-python-sdk/commit/f0828c044ba21f7cd9f7cb0922325cac5ceab33e))
* **api:** OpenAPI spec update via Stainless API ([#73](https://github.com/RetellAI/retell-python-sdk/issues/73)) ([9b4bd2a](https://github.com/RetellAI/retell-python-sdk/commit/9b4bd2a947e7860df7dc3b998436b2e5c750c715))

## 3.9.0 (2024-04-24)

Full Changelog: [v3.8.0...v3.9.0](https://github.com/RetellAI/retell-python-sdk/compare/v3.8.0...v3.9.0)

### Features

* **api:** OpenAPI spec update via Stainless API ([#62](https://github.com/RetellAI/retell-python-sdk/issues/62)) ([395ddfc](https://github.com/RetellAI/retell-python-sdk/commit/395ddfc134e881821495bc653d7c23946f5f9f08))
* **api:** OpenAPI spec update via Stainless API ([#63](https://github.com/RetellAI/retell-python-sdk/issues/63)) ([64cdc71](https://github.com/RetellAI/retell-python-sdk/commit/64cdc71301bd82f3df157db82ac1ccb9b6420fd4))
* **api:** update via SDK Studio ([#59](https://github.com/RetellAI/retell-python-sdk/issues/59)) ([a78e8c2](https://github.com/RetellAI/retell-python-sdk/commit/a78e8c246d5a8a76689707a54677dd8052047083))
* **api:** update via SDK Studio ([#61](https://github.com/RetellAI/retell-python-sdk/issues/61)) ([8d97e8d](https://github.com/RetellAI/retell-python-sdk/commit/8d97e8def8c3efb45e308fe955214e19d9d07188))
* **api:** update via SDK Studio ([#64](https://github.com/RetellAI/retell-python-sdk/issues/64)) ([211e974](https://github.com/RetellAI/retell-python-sdk/commit/211e974a22b1d10adc7484e647381c13745765cb))
* **api:** update via SDK Studio ([#65](https://github.com/RetellAI/retell-python-sdk/issues/65)) ([46a5735](https://github.com/RetellAI/retell-python-sdk/commit/46a5735c31d825696efe1da944b7029e6a8fb67f))
* **api:** update via SDK Studio ([#66](https://github.com/RetellAI/retell-python-sdk/issues/66)) ([c9e8760](https://github.com/RetellAI/retell-python-sdk/commit/c9e876011d5a62ead8ea65e492cec457c05aec49))
* **api:** update via SDK Studio ([#67](https://github.com/RetellAI/retell-python-sdk/issues/67)) ([29a4cb1](https://github.com/RetellAI/retell-python-sdk/commit/29a4cb1ee2cea8ab4cc17b74558e3ffa5ae32db4))
* **api:** update via SDK Studio ([#68](https://github.com/RetellAI/retell-python-sdk/issues/68)) ([e66008d](https://github.com/RetellAI/retell-python-sdk/commit/e66008da5eb42308b8c0d97f8f35a41d3731c27d))

## 3.8.0 (2024-04-21)

Full Changelog: [v3.7.0...v3.8.0](https://github.com/RetellAI/retell-python-sdk/compare/v3.7.0...v3.8.0)

### Features

* **api:** update via SDK Studio ([#57](https://github.com/RetellAI/retell-python-sdk/issues/57)) ([a964fb5](https://github.com/RetellAI/retell-python-sdk/commit/a964fb5861ba611c2790a1b38c9967640c6edcbf))

## 3.7.0 (2024-04-20)

Full Changelog: [v3.6.0...v3.7.0](https://github.com/RetellAI/retell-python-sdk/compare/v3.6.0...v3.7.0)

### Features

* **api:** OpenAPI spec update via Stainless API ([#55](https://github.com/RetellAI/retell-python-sdk/issues/55)) ([8c034c2](https://github.com/RetellAI/retell-python-sdk/commit/8c034c2246df61369fa9383c04d63d3d7ad9ab8c))

## 3.6.0 (2024-04-16)

Full Changelog: [v3.5.0...v3.6.0](https://github.com/RetellAI/retell-python-sdk/compare/v3.5.0...v3.6.0)

### Features

* **api:** OpenAPI spec update via Stainless API ([#51](https://github.com/RetellAI/retell-python-sdk/issues/51)) ([5207437](https://github.com/RetellAI/retell-python-sdk/commit/5207437ef2da2e59c3930526b6a576c5b17ab92b))
* **api:** OpenAPI spec update via Stainless API ([#53](https://github.com/RetellAI/retell-python-sdk/issues/53)) ([41deec0](https://github.com/RetellAI/retell-python-sdk/commit/41deec01753d2db6a4ee4cd93a91c66ef5de8b2f))
* **api:** OpenAPI spec update via Stainless API ([#54](https://github.com/RetellAI/retell-python-sdk/issues/54)) ([1a233db](https://github.com/RetellAI/retell-python-sdk/commit/1a233db002079497e5224db02a328a19f28735d0))

## 3.5.0 (2024-04-09)

Full Changelog: [v3.4.0...v3.5.0](https://github.com/RetellAI/retell-python-sdk/compare/v3.4.0...v3.5.0)

### Features

* **api:** OpenAPI spec update via Stainless API ([#40](https://github.com/RetellAI/retell-python-sdk/issues/40)) ([a03bf90](https://github.com/RetellAI/retell-python-sdk/commit/a03bf90f56a00f6eab16cd00e2b4421baf0afcdf))
* **api:** OpenAPI spec update via Stainless API ([#41](https://github.com/RetellAI/retell-python-sdk/issues/41)) ([c2cf74c](https://github.com/RetellAI/retell-python-sdk/commit/c2cf74c755453d0261044ad53b6bbec56ad648f6))
* **api:** OpenAPI spec update via Stainless API ([#43](https://github.com/RetellAI/retell-python-sdk/issues/43)) ([15d48bc](https://github.com/RetellAI/retell-python-sdk/commit/15d48bc7f60f3cd19a260feac4653d00962c0dc3))
* **api:** OpenAPI spec update via Stainless API ([#45](https://github.com/RetellAI/retell-python-sdk/issues/45)) ([5b1dd2e](https://github.com/RetellAI/retell-python-sdk/commit/5b1dd2e5f84e4b9941f09f29e7290e79edc4bc94))
* **api:** OpenAPI spec update via Stainless API ([#47](https://github.com/RetellAI/retell-python-sdk/issues/47)) ([f9de6a2](https://github.com/RetellAI/retell-python-sdk/commit/f9de6a26081ead079bddb0e849ccbe1c3f79713b))
* **api:** OpenAPI spec update via Stainless API ([#48](https://github.com/RetellAI/retell-python-sdk/issues/48)) ([679b14d](https://github.com/RetellAI/retell-python-sdk/commit/679b14de819fdde12c87eac7325620a6de1add39))
* **api:** OpenAPI spec update via Stainless API ([#49](https://github.com/RetellAI/retell-python-sdk/issues/49)) ([f6946bb](https://github.com/RetellAI/retell-python-sdk/commit/f6946bb3ebea62631153e59e9657b26b3a912b35))
* **api:** OpenAPI spec update via Stainless API ([#50](https://github.com/RetellAI/retell-python-sdk/issues/50)) ([bb493f3](https://github.com/RetellAI/retell-python-sdk/commit/bb493f3584ffa972bf61e1bc68e5ba27123baf09))
* **api:** update via SDK Studio ([#38](https://github.com/RetellAI/retell-python-sdk/issues/38)) ([ae81995](https://github.com/RetellAI/retell-python-sdk/commit/ae81995d2e60df916798bb5912165b231206b03b))
* **api:** update via SDK Studio ([#42](https://github.com/RetellAI/retell-python-sdk/issues/42)) ([edbc78a](https://github.com/RetellAI/retell-python-sdk/commit/edbc78a33640b823010d5fd7e8e252d98207a00e))
* **api:** update via SDK Studio ([#44](https://github.com/RetellAI/retell-python-sdk/issues/44)) ([4ae3374](https://github.com/RetellAI/retell-python-sdk/commit/4ae337497e4c6fed1799aa69819d57a63d59e63a))
* **api:** update via SDK Studio ([#46](https://github.com/RetellAI/retell-python-sdk/issues/46)) ([7e9f13d](https://github.com/RetellAI/retell-python-sdk/commit/7e9f13d5e0b1e621fb809d5607450294951fdd39))

## 3.4.0 (2024-04-05)

Full Changelog: [v3.3.0...v3.4.0](https://github.com/RetellAI/retell-python-sdk/compare/v3.3.0...v3.4.0)

### Features

* **api:** OpenAPI spec update via Stainless API ([#33](https://github.com/RetellAI/retell-python-sdk/issues/33)) ([e66b794](https://github.com/RetellAI/retell-python-sdk/commit/e66b79435d1375db65e1d5d5fe35d184b6bcb3b1))
* **api:** OpenAPI spec update via Stainless API ([#36](https://github.com/RetellAI/retell-python-sdk/issues/36)) ([6a640a4](https://github.com/RetellAI/retell-python-sdk/commit/6a640a4ced26ee672d5b4e649a500ea673efaa0b))
* **api:** OpenAPI spec update via Stainless API ([#37](https://github.com/RetellAI/retell-python-sdk/issues/37)) ([05fa284](https://github.com/RetellAI/retell-python-sdk/commit/05fa284ef46fc2d6c1970ace5e40a0e4079fc205))

## 3.3.0 (2024-03-29)

Full Changelog: [v3.2.0...v3.3.0](https://github.com/RetellAI/retell-python-sdk/compare/v3.2.0...v3.3.0)

### Features

* **api:** OpenAPI spec update via Stainless API ([#31](https://github.com/RetellAI/retell-python-sdk/issues/31)) ([5b83e03](https://github.com/RetellAI/retell-python-sdk/commit/5b83e0331d1a75aa7bbcb92181c9012a9cb688af))

## 3.2.0 (2024-03-28)

Full Changelog: [v3.1.0...v3.2.0](https://github.com/RetellAI/retell-python-sdk/compare/v3.1.0...v3.2.0)

### Features

* **api:** OpenAPI spec update via Stainless API ([#28](https://github.com/RetellAI/retell-python-sdk/issues/28)) ([7854389](https://github.com/RetellAI/retell-python-sdk/commit/7854389a3f89c8e25b6f4380b192f7a9d79b8e6d))
* **api:** OpenAPI spec update via Stainless API ([#30](https://github.com/RetellAI/retell-python-sdk/issues/30)) ([c35135a](https://github.com/RetellAI/retell-python-sdk/commit/c35135ac8a055afc5871567e0028bbdeefb55ad6))

## 3.1.0 (2024-03-27)

Full Changelog: [v3.0.0...v3.1.0](https://github.com/RetellAI/retell-python-sdk/compare/v3.0.0...v3.1.0)

### Features

* **api:** update via SDK Studio ([#26](https://github.com/RetellAI/retell-python-sdk/issues/26)) ([0130013](https://github.com/RetellAI/retell-python-sdk/commit/0130013d9360370b2a83ffdbb142185e26944ddd))

## 3.0.0 (2024-03-26)

Full Changelog: [v0.1.0-alpha.5...v3.0.0](https://github.com/RetellAI/retell-python-sdk/compare/v0.1.0-alpha.5...v3.0.0)

### Features

* **api:** update via SDK Studio ([37356d8](https://github.com/RetellAI/retell-python-sdk/commit/37356d8b0e0ba809e6fc7128daaac517679fb16a))
* **api:** update via SDK Studio ([8f03138](https://github.com/RetellAI/retell-python-sdk/commit/8f031387fedc79545b80ef01c12a581a7efe8f14))
* **api:** update via SDK Studio ([3ef0339](https://github.com/RetellAI/retell-python-sdk/commit/3ef03393744c78be167a4b7f20ae718bfc57a7be))
* **api:** update via SDK Studio ([c9aac94](https://github.com/RetellAI/retell-python-sdk/commit/c9aac942c63a18f2fb59b90fba665e09a841e800))
* **api:** update via SDK Studio ([290cb85](https://github.com/RetellAI/retell-python-sdk/commit/290cb852ef13a5e7dd88ef5d239c94f73b098ffa))
* **api:** update via SDK Studio ([b8221ed](https://github.com/RetellAI/retell-python-sdk/commit/b8221ede7d97a11b731ab34632861547c2eba98c))
* **api:** update via SDK Studio ([054b303](https://github.com/RetellAI/retell-python-sdk/commit/054b3037a6e47a3eec992a59e21ddae14c38b8f2))
* **api:** update via SDK Studio ([7141964](https://github.com/RetellAI/retell-python-sdk/commit/7141964d7ca6562d49bd75432c3f1d62d2e22194))
* **api:** update via SDK Studio ([07021ed](https://github.com/RetellAI/retell-python-sdk/commit/07021ed4290343ccae0093caaaece849b9622f22))
* **api:** update via SDK Studio ([bc8943b](https://github.com/RetellAI/retell-python-sdk/commit/bc8943b8f376f7c1ad90b9c68cf3238734f65136))
* **api:** update via SDK Studio ([085a1c6](https://github.com/RetellAI/retell-python-sdk/commit/085a1c6b4566596f9db1acb95c8a84d0b942f5e2))
* **api:** update via SDK Studio ([0d714d7](https://github.com/RetellAI/retell-python-sdk/commit/0d714d7504df675161eded3c95d6c7189bbd3f61))
* **api:** update via SDK Studio ([047ff47](https://github.com/RetellAI/retell-python-sdk/commit/047ff47aeca6cc1cb43e999ad94b9946c8d35514))
* **api:** update via SDK Studio ([8a3c23e](https://github.com/RetellAI/retell-python-sdk/commit/8a3c23e49948709c2b405a25533e047d69adbd98))
* **api:** update via SDK Studio ([5b35eca](https://github.com/RetellAI/retell-python-sdk/commit/5b35eca9b34b41684ab8700c21c3a9c2ecc4b070))
* **api:** update via SDK Studio ([5505d55](https://github.com/RetellAI/retell-python-sdk/commit/5505d553fd7a2270cb0ef974d9eeec42af2328b0))
* **api:** update via SDK Studio ([d6440a0](https://github.com/RetellAI/retell-python-sdk/commit/d6440a06c853e65ca51e422320e9a952a21380ba))
* **api:** update via SDK Studio ([cae2bfd](https://github.com/RetellAI/retell-python-sdk/commit/cae2bfdec3298973d0430c03c93252f6b3acac90))
* **api:** update via SDK Studio ([bbb8b5b](https://github.com/RetellAI/retell-python-sdk/commit/bbb8b5bc4b6fd329a408c9a9550650946627abb2))
* **api:** update via SDK Studio ([5f99a59](https://github.com/RetellAI/retell-python-sdk/commit/5f99a59a97604b6c3f59e0032979efd206d402ce))
* **api:** update via SDK Studio ([e0b7fe3](https://github.com/RetellAI/retell-python-sdk/commit/e0b7fe38077c86e86766d219c2b12f036a3bff4d))
* **api:** update via SDK Studio ([#4](https://github.com/RetellAI/retell-python-sdk/issues/4)) ([470446d](https://github.com/RetellAI/retell-python-sdk/commit/470446dabd1e8a3f371d817debcce760c7566aca))
* **api:** update via SDK Studio ([#6](https://github.com/RetellAI/retell-python-sdk/issues/6)) ([d0018ba](https://github.com/RetellAI/retell-python-sdk/commit/d0018ba83f53b5f9ba729287eb1e7417705c94f9))
* **api:** update via SDK Studio ([#8](https://github.com/RetellAI/retell-python-sdk/issues/8)) ([073a0ff](https://github.com/RetellAI/retell-python-sdk/commit/073a0ff186f381023818aade9d2ec909a93d4137))
* **api:** update via SDK Studio ([#9](https://github.com/RetellAI/retell-python-sdk/issues/9)) ([ed6dfba](https://github.com/RetellAI/retell-python-sdk/commit/ed6dfbac3ddf20c1ee8a9ff78ab6e23df1be1a85))
* OpenAPI spec update ([6dbed1a](https://github.com/RetellAI/retell-python-sdk/commit/6dbed1a8a382913ed6d81ab52dbbec37019a4cde))


### Chores

* go live ([#2](https://github.com/RetellAI/retell-python-sdk/issues/2)) ([a7ea29d](https://github.com/RetellAI/retell-python-sdk/commit/a7ea29d9d2c2680bed319eed192094f22f1265ad))

## 0.1.0-alpha.5 (2024-03-26)

Full Changelog: [v0.1.0-alpha.4...v0.1.0-alpha.5](https://github.com/RetellAI/retell-python-sdk/compare/v0.1.0-alpha.4...v0.1.0-alpha.5)

### Features

* **api:** update via SDK Studio ([37356d8](https://github.com/RetellAI/retell-python-sdk/commit/37356d8b0e0ba809e6fc7128daaac517679fb16a))
* **api:** update via SDK Studio ([8f03138](https://github.com/RetellAI/retell-python-sdk/commit/8f031387fedc79545b80ef01c12a581a7efe8f14))
* **api:** update via SDK Studio ([3ef0339](https://github.com/RetellAI/retell-python-sdk/commit/3ef03393744c78be167a4b7f20ae718bfc57a7be))
* **api:** update via SDK Studio ([c9aac94](https://github.com/RetellAI/retell-python-sdk/commit/c9aac942c63a18f2fb59b90fba665e09a841e800))
* **api:** update via SDK Studio ([290cb85](https://github.com/RetellAI/retell-python-sdk/commit/290cb852ef13a5e7dd88ef5d239c94f73b098ffa))
* **api:** update via SDK Studio ([b8221ed](https://github.com/RetellAI/retell-python-sdk/commit/b8221ede7d97a11b731ab34632861547c2eba98c))
* **api:** update via SDK Studio ([054b303](https://github.com/RetellAI/retell-python-sdk/commit/054b3037a6e47a3eec992a59e21ddae14c38b8f2))
* **api:** update via SDK Studio ([7141964](https://github.com/RetellAI/retell-python-sdk/commit/7141964d7ca6562d49bd75432c3f1d62d2e22194))
* **api:** update via SDK Studio ([07021ed](https://github.com/RetellAI/retell-python-sdk/commit/07021ed4290343ccae0093caaaece849b9622f22))
* **api:** update via SDK Studio ([bc8943b](https://github.com/RetellAI/retell-python-sdk/commit/bc8943b8f376f7c1ad90b9c68cf3238734f65136))
* **api:** update via SDK Studio ([085a1c6](https://github.com/RetellAI/retell-python-sdk/commit/085a1c6b4566596f9db1acb95c8a84d0b942f5e2))
* **api:** update via SDK Studio ([0d714d7](https://github.com/RetellAI/retell-python-sdk/commit/0d714d7504df675161eded3c95d6c7189bbd3f61))
* **api:** update via SDK Studio ([047ff47](https://github.com/RetellAI/retell-python-sdk/commit/047ff47aeca6cc1cb43e999ad94b9946c8d35514))
* **api:** update via SDK Studio ([8a3c23e](https://github.com/RetellAI/retell-python-sdk/commit/8a3c23e49948709c2b405a25533e047d69adbd98))
* **api:** update via SDK Studio ([5b35eca](https://github.com/RetellAI/retell-python-sdk/commit/5b35eca9b34b41684ab8700c21c3a9c2ecc4b070))
* **api:** update via SDK Studio ([5505d55](https://github.com/RetellAI/retell-python-sdk/commit/5505d553fd7a2270cb0ef974d9eeec42af2328b0))
* **api:** update via SDK Studio ([d6440a0](https://github.com/RetellAI/retell-python-sdk/commit/d6440a06c853e65ca51e422320e9a952a21380ba))
* **api:** update via SDK Studio ([cae2bfd](https://github.com/RetellAI/retell-python-sdk/commit/cae2bfdec3298973d0430c03c93252f6b3acac90))
* **api:** update via SDK Studio ([bbb8b5b](https://github.com/RetellAI/retell-python-sdk/commit/bbb8b5bc4b6fd329a408c9a9550650946627abb2))
* **api:** update via SDK Studio ([5f99a59](https://github.com/RetellAI/retell-python-sdk/commit/5f99a59a97604b6c3f59e0032979efd206d402ce))
* **api:** update via SDK Studio ([e0b7fe3](https://github.com/RetellAI/retell-python-sdk/commit/e0b7fe38077c86e86766d219c2b12f036a3bff4d))
* **api:** update via SDK Studio ([#4](https://github.com/RetellAI/retell-python-sdk/issues/4)) ([470446d](https://github.com/RetellAI/retell-python-sdk/commit/470446dabd1e8a3f371d817debcce760c7566aca))
* **api:** update via SDK Studio ([#6](https://github.com/RetellAI/retell-python-sdk/issues/6)) ([d0018ba](https://github.com/RetellAI/retell-python-sdk/commit/d0018ba83f53b5f9ba729287eb1e7417705c94f9))
* **api:** update via SDK Studio ([#8](https://github.com/RetellAI/retell-python-sdk/issues/8)) ([073a0ff](https://github.com/RetellAI/retell-python-sdk/commit/073a0ff186f381023818aade9d2ec909a93d4137))
* **api:** update via SDK Studio ([#9](https://github.com/RetellAI/retell-python-sdk/issues/9)) ([ed6dfba](https://github.com/RetellAI/retell-python-sdk/commit/ed6dfbac3ddf20c1ee8a9ff78ab6e23df1be1a85))
* OpenAPI spec update ([6dbed1a](https://github.com/RetellAI/retell-python-sdk/commit/6dbed1a8a382913ed6d81ab52dbbec37019a4cde))


### Chores

* go live ([#2](https://github.com/RetellAI/retell-python-sdk/issues/2)) ([a7ea29d](https://github.com/RetellAI/retell-python-sdk/commit/a7ea29d9d2c2680bed319eed192094f22f1265ad))

## 0.1.0-alpha.4 (2024-03-26)

Full Changelog: [v0.1.0-alpha.3...v0.1.0-alpha.4](https://github.com/RetellAI/retell-python-sdk/compare/v0.1.0-alpha.3...v0.1.0-alpha.4)

### Features

* **api:** update via SDK Studio ([#9](https://github.com/RetellAI/retell-python-sdk/issues/9)) ([ed6dfba](https://github.com/RetellAI/retell-python-sdk/commit/ed6dfbac3ddf20c1ee8a9ff78ab6e23df1be1a85))

## 0.1.0-alpha.3 (2024-03-26)

Full Changelog: [v0.1.0-alpha.2...v0.1.0-alpha.3](https://github.com/RetellAI/retell-python-sdk/compare/v0.1.0-alpha.2...v0.1.0-alpha.3)

### Features

* **api:** update via SDK Studio ([#6](https://github.com/RetellAI/retell-python-sdk/issues/6)) ([d0018ba](https://github.com/RetellAI/retell-python-sdk/commit/d0018ba83f53b5f9ba729287eb1e7417705c94f9))
* **api:** update via SDK Studio ([#8](https://github.com/RetellAI/retell-python-sdk/issues/8)) ([073a0ff](https://github.com/RetellAI/retell-python-sdk/commit/073a0ff186f381023818aade9d2ec909a93d4137))

## 0.1.0-alpha.2 (2024-03-26)

Full Changelog: [v0.1.0-alpha.1...v0.1.0-alpha.2](https://github.com/RetellAI/retell-python-sdk/compare/v0.1.0-alpha.1...v0.1.0-alpha.2)

### Features

* **api:** update via SDK Studio ([#4](https://github.com/RetellAI/retell-python-sdk/issues/4)) ([470446d](https://github.com/RetellAI/retell-python-sdk/commit/470446dabd1e8a3f371d817debcce760c7566aca))

## 0.1.0-alpha.1 (2024-03-26)

Full Changelog: [v0.0.1-alpha.0...v0.1.0-alpha.1](https://github.com/RetellAI/retell-python-sdk/compare/v0.0.1-alpha.0...v0.1.0-alpha.1)

### Features

* **api:** update via SDK Studio ([37356d8](https://github.com/RetellAI/retell-python-sdk/commit/37356d8b0e0ba809e6fc7128daaac517679fb16a))
* **api:** update via SDK Studio ([8f03138](https://github.com/RetellAI/retell-python-sdk/commit/8f031387fedc79545b80ef01c12a581a7efe8f14))
* **api:** update via SDK Studio ([3ef0339](https://github.com/RetellAI/retell-python-sdk/commit/3ef03393744c78be167a4b7f20ae718bfc57a7be))
* **api:** update via SDK Studio ([c9aac94](https://github.com/RetellAI/retell-python-sdk/commit/c9aac942c63a18f2fb59b90fba665e09a841e800))
* **api:** update via SDK Studio ([290cb85](https://github.com/RetellAI/retell-python-sdk/commit/290cb852ef13a5e7dd88ef5d239c94f73b098ffa))
* **api:** update via SDK Studio ([b8221ed](https://github.com/RetellAI/retell-python-sdk/commit/b8221ede7d97a11b731ab34632861547c2eba98c))
* **api:** update via SDK Studio ([054b303](https://github.com/RetellAI/retell-python-sdk/commit/054b3037a6e47a3eec992a59e21ddae14c38b8f2))
* **api:** update via SDK Studio ([7141964](https://github.com/RetellAI/retell-python-sdk/commit/7141964d7ca6562d49bd75432c3f1d62d2e22194))
* **api:** update via SDK Studio ([07021ed](https://github.com/RetellAI/retell-python-sdk/commit/07021ed4290343ccae0093caaaece849b9622f22))
* **api:** update via SDK Studio ([bc8943b](https://github.com/RetellAI/retell-python-sdk/commit/bc8943b8f376f7c1ad90b9c68cf3238734f65136))
* **api:** update via SDK Studio ([085a1c6](https://github.com/RetellAI/retell-python-sdk/commit/085a1c6b4566596f9db1acb95c8a84d0b942f5e2))
* **api:** update via SDK Studio ([0d714d7](https://github.com/RetellAI/retell-python-sdk/commit/0d714d7504df675161eded3c95d6c7189bbd3f61))
* **api:** update via SDK Studio ([047ff47](https://github.com/RetellAI/retell-python-sdk/commit/047ff47aeca6cc1cb43e999ad94b9946c8d35514))
* **api:** update via SDK Studio ([8a3c23e](https://github.com/RetellAI/retell-python-sdk/commit/8a3c23e49948709c2b405a25533e047d69adbd98))
* **api:** update via SDK Studio ([5b35eca](https://github.com/RetellAI/retell-python-sdk/commit/5b35eca9b34b41684ab8700c21c3a9c2ecc4b070))
* **api:** update via SDK Studio ([5505d55](https://github.com/RetellAI/retell-python-sdk/commit/5505d553fd7a2270cb0ef974d9eeec42af2328b0))
* **api:** update via SDK Studio ([d6440a0](https://github.com/RetellAI/retell-python-sdk/commit/d6440a06c853e65ca51e422320e9a952a21380ba))
* **api:** update via SDK Studio ([cae2bfd](https://github.com/RetellAI/retell-python-sdk/commit/cae2bfdec3298973d0430c03c93252f6b3acac90))
* **api:** update via SDK Studio ([bbb8b5b](https://github.com/RetellAI/retell-python-sdk/commit/bbb8b5bc4b6fd329a408c9a9550650946627abb2))
* **api:** update via SDK Studio ([5f99a59](https://github.com/RetellAI/retell-python-sdk/commit/5f99a59a97604b6c3f59e0032979efd206d402ce))
* **api:** update via SDK Studio ([e0b7fe3](https://github.com/RetellAI/retell-python-sdk/commit/e0b7fe38077c86e86766d219c2b12f036a3bff4d))
* OpenAPI spec update ([6dbed1a](https://github.com/RetellAI/retell-python-sdk/commit/6dbed1a8a382913ed6d81ab52dbbec37019a4cde))


### Chores

* go live ([#2](https://github.com/RetellAI/retell-python-sdk/issues/2)) ([a7ea29d](https://github.com/RetellAI/retell-python-sdk/commit/a7ea29d9d2c2680bed319eed192094f22f1265ad))
